/*===========================================================================*/
/*   (Bdb/bdb_initialize.scm)                                                */
/*   Bigloo (4.6a)                                                           */
/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
/*===========================================================================*/
/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Bdb/bdb_initialize.scm) */
/* GC selection */
#define THE_GC BOEHM_GC

/* unsafe mode */
#define BIGLOO_UNSAFE 1

/* traces mode */
#define BIGLOO_TRACE 0

/* standard Bigloo include */
#include <bigloo.h>

#ifdef __cplusplus
extern "C"
{
#endif
#ifndef BGL_MODULE_TYPE_DEFINITIONS
#define BGL_MODULE_TYPE_DEFINITIONS
#ifndef BGL_BDB_INITIALIZE_TYPE_DEFINITIONS
#define BGL_BDB_INITIALIZE_TYPE_DEFINITIONS

/* object type definitions */
	typedef struct BgL_typez00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_idz00;
		obj_t BgL_namez00;
		obj_t BgL_siza7eza7;
		obj_t BgL_classz00;
		obj_t BgL_coercezd2tozd2;
		obj_t BgL_parentsz00;
		bool_t BgL_initzf3zf3;
		bool_t BgL_magiczf3zf3;
		obj_t BgL_nullz00;
		obj_t BgL_z42z42;
		obj_t BgL_aliasz00;
		obj_t BgL_pointedzd2tozd2byz00;
		obj_t BgL_tvectorz00;
		obj_t BgL_locationz00;
		obj_t BgL_importzd2locationzd2;
		int BgL_occurrencez00;
	}              *BgL_typez00_bglt;

	typedef struct BgL_valuez00_bgl
	{
		header_t header;
		obj_t widening;
	}               *BgL_valuez00_bglt;

	typedef struct BgL_variablez00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_idz00;
		obj_t BgL_namez00;
		struct BgL_typez00_bgl *BgL_typez00;
		struct BgL_valuez00_bgl *BgL_valuez00;
		obj_t BgL_accessz00;
		obj_t BgL_fastzd2alphazd2;
		obj_t BgL_removablez00;
		long BgL_occurrencez00;
		long BgL_occurrencewz00;
		bool_t BgL_userzf3zf3;
	}                  *BgL_variablez00_bglt;

	typedef struct BgL_globalz00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_idz00;
		obj_t BgL_namez00;
		struct BgL_typez00_bgl *BgL_typez00;
		struct BgL_valuez00_bgl *BgL_valuez00;
		obj_t BgL_accessz00;
		obj_t BgL_fastzd2alphazd2;
		obj_t BgL_removablez00;
		long BgL_occurrencez00;
		long BgL_occurrencewz00;
		bool_t BgL_userzf3zf3;
		obj_t BgL_modulez00;
		obj_t BgL_importz00;
		bool_t BgL_evaluablezf3zf3;
		bool_t BgL_evalzf3zf3;
		obj_t BgL_libraryz00;
		obj_t BgL_pragmaz00;
		obj_t BgL_srcz00;
		obj_t BgL_qualifiedzd2typezd2namez00;
		obj_t BgL_initz00;
		obj_t BgL_aliasz00;
	}                *BgL_globalz00_bglt;

	typedef struct BgL_sfunz00_bgl
	{
		header_t header;
		obj_t widening;
		long BgL_arityz00;
		obj_t BgL_sidezd2effectzd2;
		obj_t BgL_predicatezd2ofzd2;
		obj_t BgL_stackzd2allocatorzd2;
		bool_t BgL_topzf3zf3;
		obj_t BgL_thezd2closurezd2;
		obj_t BgL_effectz00;
		obj_t BgL_failsafez00;
		obj_t BgL_argszd2noescapezd2;
		obj_t BgL_argszd2retescapezd2;
		obj_t BgL_propertyz00;
		obj_t BgL_argsz00;
		obj_t BgL_argszd2namezd2;
		obj_t BgL_bodyz00;
		obj_t BgL_classz00;
		obj_t BgL_dssslzd2keywordszd2;
		obj_t BgL_locz00;
		obj_t BgL_optionalsz00;
		obj_t BgL_keysz00;
		obj_t BgL_thezd2closurezd2globalz00;
		obj_t BgL_strengthz00;
		obj_t BgL_stackablez00;
	}              *BgL_sfunz00_bglt;

	typedef struct BgL_nodez00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_locz00;
		struct BgL_typez00_bgl *BgL_typez00;
	}              *BgL_nodez00_bglt;


#endif													// BGL_BDB_INITIALIZE_TYPE_DEFINITIONS
#endif													// BGL_MODULE_TYPE_DEFINITIONS

	static obj_t BGl_requirezd2initializa7ationz75zzbdb_initializa7eza7 = BUNSPEC;
	static obj_t BGl_toplevelzd2initzd2zzbdb_initializa7eza7(void);
	static obj_t BGl_genericzd2initzd2zzbdb_initializa7eza7(void);
	static obj_t BGl_objectzd2initzd2zzbdb_initializa7eza7(void);
	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
	BGL_IMPORT obj_t BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00(obj_t,
		obj_t, obj_t);
	static obj_t BGl_methodzd2initzd2zzbdb_initializa7eza7(void);
	extern BgL_nodez00_bglt BGl_coercez12z12zzcoerce_coercez00(BgL_nodez00_bglt,
		obj_t, BgL_typez00_bglt, bool_t);
	extern obj_t BGl_za2moduleza2z00zzmodule_modulez00;
	extern obj_t BGl_buildzd2astzd2zzast_buildz00(obj_t);
	static obj_t BGl_z62initializa7ezd2astz17zzbdb_initializa7eza7(obj_t);
	BGL_EXPORTED_DECL obj_t
		BGl_modulezd2initializa7ationz75zzbdb_initializa7eza7(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcnst_nodez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcnst_allocz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzcoerce_coercez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_glozd2defzd2(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_lvtypez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_buildz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_envz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_nodez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_varz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztype_cachez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztype_typez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzmodule_modulez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzengine_paramz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_errorz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_speekz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_shapez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_tracez00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(long,
		char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__readerz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__structurez00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__biglooz00(long, char *);
	BGL_IMPORT obj_t create_struct(obj_t, int);
	static obj_t BGl_cnstzd2initzd2zzbdb_initializa7eza7(void);
	static obj_t BGl_libraryzd2moduleszd2initz00zzbdb_initializa7eza7(void);
	static obj_t BGl_importedzd2moduleszd2initz00zzbdb_initializa7eza7(void);
	static obj_t BGl_gczd2rootszd2initz00zzbdb_initializa7eza7(void);
	BGL_EXPORTED_DECL obj_t BGl_initializa7ezd2astz75zzbdb_initializa7eza7(void);
	static obj_t __cnst[5];


	   
		 
		DEFINE_STRING(BGl_string1363z00zzbdb_initializa7eza7,
		BgL_bgl_string1363za700za7za7b1368za7, "((obj_t)__bdb_info)", 19);
	      DEFINE_STRING(BGl_string1364z00zzbdb_initializa7eza7,
		BgL_bgl_string1364za700za7za7b1369za7, "bdb_initialize", 14);
	      DEFINE_STRING(BGl_string1365z00zzbdb_initializa7eza7,
		BgL_bgl_string1365za700za7za7b1370za7,
		"unit bdb bdb-set-module-info! pragma::obj quote ", 48);
	     
		DEFINE_EXPORT_BGL_PROCEDURE
		(BGl_initializa7ezd2astzd2envza7zzbdb_initializa7eza7,
		BgL_bgl_za762initializa7a7eza71371za7,
		BGl_z62initializa7ezd2astz17zzbdb_initializa7eza7, 0L, BUNSPEC, 0);

/* GC roots registration */
	static obj_t bgl_gc_roots_register()
	{
#if defined( BGL_GC_ROOTS )
#define ADD_ROOT( addr ) (addr > roots_max ? roots_max = addr : (addr < roots_min ? roots_min = addr : 0))
		void *roots_min = (void *) ULONG_MAX, *roots_max = 0;
		   
			 ADD_ROOT((void
				*) (&BGl_requirezd2initializa7ationz75zzbdb_initializa7eza7));
#undef ADD_ROOT
		if   (roots_max > 0)
			     GC_add_roots(roots_min, ((void **) roots_max) + 1);
#endif
		     return BUNSPEC;
	}



/* module-initialization */
	BGL_EXPORTED_DEF obj_t
		BGl_modulezd2initializa7ationz75zzbdb_initializa7eza7(long
		BgL_checksumz00_1624, char *BgL_fromz00_1625)
	{
		{
			if (CBOOL(BGl_requirezd2initializa7ationz75zzbdb_initializa7eza7))
				{
					BGl_requirezd2initializa7ationz75zzbdb_initializa7eza7 =
						BBOOL(((bool_t) 0));
					BGl_gczd2rootszd2initz00zzbdb_initializa7eza7();
					BGl_libraryzd2moduleszd2initz00zzbdb_initializa7eza7();
					BGl_cnstzd2initzd2zzbdb_initializa7eza7();
					BGl_importedzd2moduleszd2initz00zzbdb_initializa7eza7();
					return BGl_toplevelzd2initzd2zzbdb_initializa7eza7();
				}
			else
				{
					return BUNSPEC;
				}
		}

	}



/* library-modules-init */
	obj_t BGl_libraryzd2moduleszd2initz00zzbdb_initializa7eza7(void)
	{
		{	/* Bdb/bdb_initialize.scm 15 */
			BGl_modulezd2initializa7ationz75zz__readerz00(0L, "bdb_initialize");
			BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(0L,
				"bdb_initialize");
			BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(0L,
				"bdb_initialize");
			BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(0L,
				"bdb_initialize");
			BGl_modulezd2initializa7ationz75zz__structurez00(0L, "bdb_initialize");
			BGl_modulezd2initializa7ationz75zz__biglooz00(0L, "bdb_initialize");
			return BUNSPEC;
		}

	}



/* cnst-init */
	obj_t BGl_cnstzd2initzd2zzbdb_initializa7eza7(void)
	{
		{	/* Bdb/bdb_initialize.scm 15 */
			{	/* Bdb/bdb_initialize.scm 15 */
				obj_t BgL_cportz00_1613;

				{	/* Bdb/bdb_initialize.scm 15 */
					obj_t BgL_stringz00_1620;

					BgL_stringz00_1620 = BGl_string1365z00zzbdb_initializa7eza7;
					{	/* Bdb/bdb_initialize.scm 15 */
						obj_t BgL_startz00_1621;

						BgL_startz00_1621 = BINT(0L);
						{	/* Bdb/bdb_initialize.scm 15 */
							obj_t BgL_endz00_1622;

							BgL_endz00_1622 =
								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1620)));
							{	/* Bdb/bdb_initialize.scm 15 */

								BgL_cportz00_1613 =
									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
									(BgL_stringz00_1620, BgL_startz00_1621, BgL_endz00_1622);
				}}}}
				{
					long BgL_iz00_1614;

					BgL_iz00_1614 = 4L;
				BgL_loopz00_1615:
					if ((BgL_iz00_1614 == (-1L)))
						{	/* Bdb/bdb_initialize.scm 15 */
							return BUNSPEC;
						}
					else
						{	/* Bdb/bdb_initialize.scm 15 */
							{	/* Bdb/bdb_initialize.scm 15 */
								obj_t BgL_arg1367z00_1616;

								{	/* Bdb/bdb_initialize.scm 15 */

									{	/* Bdb/bdb_initialize.scm 15 */
										obj_t BgL_locationz00_1618;

										BgL_locationz00_1618 = BBOOL(((bool_t) 0));
										{	/* Bdb/bdb_initialize.scm 15 */

											BgL_arg1367z00_1616 =
												BGl_readz00zz__readerz00(BgL_cportz00_1613,
												BgL_locationz00_1618);
										}
									}
								}
								{	/* Bdb/bdb_initialize.scm 15 */
									int BgL_tmpz00_1649;

									BgL_tmpz00_1649 = (int) (BgL_iz00_1614);
									CNST_TABLE_SET(BgL_tmpz00_1649, BgL_arg1367z00_1616);
							}}
							{	/* Bdb/bdb_initialize.scm 15 */
								int BgL_auxz00_1619;

								BgL_auxz00_1619 = (int) ((BgL_iz00_1614 - 1L));
								{
									long BgL_iz00_1654;

									BgL_iz00_1654 = (long) (BgL_auxz00_1619);
									BgL_iz00_1614 = BgL_iz00_1654;
									goto BgL_loopz00_1615;
								}
							}
						}
				}
			}
		}

	}



/* gc-roots-init */
	obj_t BGl_gczd2rootszd2initz00zzbdb_initializa7eza7(void)
	{
		{	/* Bdb/bdb_initialize.scm 15 */
			return bgl_gc_roots_register();
		}

	}



/* toplevel-init */
	obj_t BGl_toplevelzd2initzd2zzbdb_initializa7eza7(void)
	{
		{	/* Bdb/bdb_initialize.scm 15 */
			return BUNSPEC;
		}

	}



/* initialize-ast */
	BGL_EXPORTED_DEF obj_t BGl_initializa7ezd2astz75zzbdb_initializa7eza7(void)
	{
		{	/* Bdb/bdb_initialize.scm 42 */
			{	/* Bdb/bdb_initialize.scm 44 */
				obj_t BgL_bodyz00_1402;

				{	/* Bdb/bdb_initialize.scm 44 */
					obj_t BgL_arg1266z00_1417;

					{	/* Bdb/bdb_initialize.scm 44 */
						obj_t BgL_arg1267z00_1418;

						{	/* Bdb/bdb_initialize.scm 44 */
							obj_t BgL_arg1268z00_1419;
							obj_t BgL_arg1271z00_1420;

							{	/* Bdb/bdb_initialize.scm 44 */
								obj_t BgL_arg1272z00_1421;

								BgL_arg1272z00_1421 =
									MAKE_YOUNG_PAIR(BGl_za2moduleza2z00zzmodule_modulez00, BNIL);
								BgL_arg1268z00_1419 =
									MAKE_YOUNG_PAIR(
									((obj_t) CNST_TABLE_REF(0)), BgL_arg1272z00_1421);
							}
							{	/* Bdb/bdb_initialize.scm 45 */
								obj_t BgL_arg1273z00_1422;

								{	/* Bdb/bdb_initialize.scm 45 */
									obj_t BgL_arg1274z00_1423;

									BgL_arg1274z00_1423 =
										MAKE_YOUNG_PAIR(BGl_string1363z00zzbdb_initializa7eza7,
										BNIL);
									BgL_arg1273z00_1422 =
										MAKE_YOUNG_PAIR(((obj_t) CNST_TABLE_REF(1)),
										BgL_arg1274z00_1423);
								}
								BgL_arg1271z00_1420 =
									MAKE_YOUNG_PAIR(BgL_arg1273z00_1422, BNIL);
							}
							BgL_arg1267z00_1418 =
								MAKE_YOUNG_PAIR(BgL_arg1268z00_1419, BgL_arg1271z00_1420);
						}
						BgL_arg1266z00_1417 =
							MAKE_YOUNG_PAIR(((obj_t) CNST_TABLE_REF(2)), BgL_arg1267z00_1418);
					}
					BgL_bodyz00_1402 = MAKE_YOUNG_PAIR(BgL_arg1266z00_1417, BNIL);
				}
				{	/* Bdb/bdb_initialize.scm 46 */
					obj_t BgL_unitz00_1403;

					{	/* Bdb/bdb_initialize.scm 46 */
						obj_t BgL_idz00_1598;

						BgL_idz00_1598 = ((obj_t) CNST_TABLE_REF(3));
						{	/* Bdb/bdb_initialize.scm 46 */
							obj_t BgL_newz00_1599;

							BgL_newz00_1599 =
								create_struct(((obj_t) CNST_TABLE_REF(4)), (int) (5L));
							{	/* Bdb/bdb_initialize.scm 46 */
								int BgL_tmpz00_1677;

								BgL_tmpz00_1677 = (int) (4L);
								STRUCT_SET(BgL_newz00_1599, BgL_tmpz00_1677, BFALSE);
							}
							{	/* Bdb/bdb_initialize.scm 46 */
								int BgL_tmpz00_1680;

								BgL_tmpz00_1680 = (int) (3L);
								STRUCT_SET(BgL_newz00_1599, BgL_tmpz00_1680, BTRUE);
							}
							{	/* Bdb/bdb_initialize.scm 46 */
								int BgL_tmpz00_1683;

								BgL_tmpz00_1683 = (int) (2L);
								STRUCT_SET(BgL_newz00_1599, BgL_tmpz00_1683, BgL_bodyz00_1402);
							}
							{	/* Bdb/bdb_initialize.scm 46 */
								obj_t BgL_auxz00_1688;
								int BgL_tmpz00_1686;

								BgL_auxz00_1688 = BINT(9L);
								BgL_tmpz00_1686 = (int) (1L);
								STRUCT_SET(BgL_newz00_1599, BgL_tmpz00_1686, BgL_auxz00_1688);
							}
							{	/* Bdb/bdb_initialize.scm 46 */
								int BgL_tmpz00_1691;

								BgL_tmpz00_1691 = (int) (0L);
								STRUCT_SET(BgL_newz00_1599, BgL_tmpz00_1691, BgL_idz00_1598);
							}
							BgL_unitz00_1403 = BgL_newz00_1599;
					}}
					{	/* Bdb/bdb_initialize.scm 47 */
						obj_t BgL_astz00_1404;

						{	/* Bdb/bdb_initialize.scm 47 */
							obj_t BgL_arg1262z00_1415;

							{	/* Bdb/bdb_initialize.scm 47 */
								obj_t BgL_list1263z00_1416;

								BgL_list1263z00_1416 = MAKE_YOUNG_PAIR(BgL_unitz00_1403, BNIL);
								BgL_arg1262z00_1415 = BgL_list1263z00_1416;
							}
							BgL_astz00_1404 =
								BGl_buildzd2astzd2zzast_buildz00(BgL_arg1262z00_1415);
						}
						{
							obj_t BgL_l1226z00_1406;

							BgL_l1226z00_1406 = BgL_astz00_1404;
						BgL_zc3z04anonymousza31253ze3z87_1407:
							if (PAIRP(BgL_l1226z00_1406))
								{	/* Bdb/bdb_initialize.scm 48 */
									{	/* Bdb/bdb_initialize.scm 49 */
										obj_t BgL_globalz00_1409;

										BgL_globalz00_1409 = CAR(BgL_l1226z00_1406);
										{	/* Bdb/bdb_initialize.scm 49 */
											obj_t BgL_arg1255z00_1410;
											BgL_typez00_bglt BgL_arg1256z00_1411;

											BgL_arg1255z00_1410 =
												(((BgL_sfunz00_bglt) COBJECT(
														((BgL_sfunz00_bglt)
															(((BgL_variablez00_bglt) COBJECT(
																		((BgL_variablez00_bglt)
																			((BgL_globalz00_bglt)
																				BgL_globalz00_1409))))->
																BgL_valuez00))))->BgL_bodyz00);
											BgL_arg1256z00_1411 =
												(((BgL_variablez00_bglt)
													COBJECT(((BgL_variablez00_bglt) ((BgL_globalz00_bglt)
																BgL_globalz00_1409))))->BgL_typez00);
											BGl_coercez12z12zzcoerce_coercez00(((BgL_nodez00_bglt)
													BgL_arg1255z00_1410), BgL_globalz00_1409,
												BgL_arg1256z00_1411, ((bool_t) 0));
										}
									}
									{
										obj_t BgL_l1226z00_1709;

										BgL_l1226z00_1709 = CDR(BgL_l1226z00_1406);
										BgL_l1226z00_1406 = BgL_l1226z00_1709;
										goto BgL_zc3z04anonymousza31253ze3z87_1407;
									}
								}
							else
								{	/* Bdb/bdb_initialize.scm 48 */
									((bool_t) 1);
								}
						}
						return BgL_astz00_1404;
					}
				}
			}
		}

	}



/* &initialize-ast */
	obj_t BGl_z62initializa7ezd2astz17zzbdb_initializa7eza7(obj_t BgL_envz00_1611)
	{
		{	/* Bdb/bdb_initialize.scm 42 */
			return BGl_initializa7ezd2astz75zzbdb_initializa7eza7();
		}

	}



/* object-init */
	obj_t BGl_objectzd2initzd2zzbdb_initializa7eza7(void)
	{
		{	/* Bdb/bdb_initialize.scm 15 */
			return BUNSPEC;
		}

	}



/* generic-init */
	obj_t BGl_genericzd2initzd2zzbdb_initializa7eza7(void)
	{
		{	/* Bdb/bdb_initialize.scm 15 */
			return BUNSPEC;
		}

	}



/* method-init */
	obj_t BGl_methodzd2initzd2zzbdb_initializa7eza7(void)
	{
		{	/* Bdb/bdb_initialize.scm 15 */
			return BUNSPEC;
		}

	}



/* imported-modules-init */
	obj_t BGl_importedzd2moduleszd2initz00zzbdb_initializa7eza7(void)
	{
		{	/* Bdb/bdb_initialize.scm 15 */
			BGl_modulezd2initializa7ationz75zztools_tracez00(54713316L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zzmodule_modulez00(158397907L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zztype_cachez00(489890788L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zzast_envz00(146730773L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zzast_buildz00(428035925L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zzast_lvtypez00(189769752L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zzast_glozd2defzd2(44601789L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zzcoerce_coercez00(361167184L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			BGl_modulezd2initializa7ationz75zzcnst_allocz00(117763019L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
			return
				BGl_modulezd2initializa7ationz75zzcnst_nodez00(89013043L,
				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
		}

	}

#ifdef __cplusplus
}
#endif
